"""
    EMIL GdvService

    The EMIL GdvService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.accounting
from eis.accounting.api.zip_codes_api import ZipCodesApi  # noqa: E501


class TestZipCodesApi(unittest.TestCase):
    """ZipCodesApi unit test stubs"""

    def setUp(self):
        self.api = ZipCodesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_zip_code(self):
        """Test case for get_zip_code

        Retrieve the zip code  # noqa: E501
        """
        pass

    def test_list_zip_codes(self):
        """Test case for list_zip_codes

        List zip codes  # noqa: E501
        """
        pass

    def test_store_zip_codes(self):
        """Test case for store_zip_codes

        Create the zip codes  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
