"""
    EMIL GdvService

    The EMIL GdvService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.accounting
from eis.accounting.api.mailbox_api import MailboxApi  # noqa: E501


class TestMailboxApi(unittest.TestCase):
    """MailboxApi unit test stubs"""

    def setUp(self):
        self.api = MailboxApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_mailbox(self):
        """Test case for create_mailbox

        Create the Mailbox  # noqa: E501
        """
        pass

    def test_download_messages(self):
        """Test case for download_messages

        Create the download-messages  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
