"""
    EMIL GdvService

    The EMIL GdvService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.accounting
from eis.accounting.model.response_message_class import ResponseMessageClass
globals()['ResponseMessageClass'] = ResponseMessageClass
from eis.accounting.model.update_response_message_response_class import UpdateResponseMessageResponseClass


class TestUpdateResponseMessageResponseClass(unittest.TestCase):
    """UpdateResponseMessageResponseClass unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testUpdateResponseMessageResponseClass(self):
        """Test UpdateResponseMessageResponseClass"""
        # FIXME: construct object with mandatory attributes with example values
        # model = UpdateResponseMessageResponseClass()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
