"""
    EMIL GdvService

    The EMIL GdvService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.accounting
from eis.accounting.api.users_api import UsersApi  # noqa: E501


class TestUsersApi(unittest.TestCase):
    """UsersApi unit test stubs"""

    def setUp(self):
        self.api = UsersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_user(self):
        """Test case for create_user

        Create the gdv tenant user  # noqa: E501
        """
        pass

    def test_get_user(self):
        """Test case for get_user

        Retrieve the gdv tenant user  # noqa: E501
        """
        pass

    def test_list_users(self):
        """Test case for list_users

        List gdv tenant users  # noqa: E501
        """
        pass

    def test_update_user(self):
        """Test case for update_user

        Update the gdv tenant user  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
