"""
    EMIL GdvService

    The EMIL GdvService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.accounting
from eis.accounting.api.vbus_api import VbusApi  # noqa: E501


class TestVbusApi(unittest.TestCase):
    """VbusApi unit test stubs"""

    def setUp(self):
        self.api = VbusApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_vbu(self):
        """Test case for create_vbu

        Create the vbu  # noqa: E501
        """
        pass

    def test_create_vbuv(self):
        """Test case for create_vbuv

        Create the vbu  # noqa: E501
        """
        pass

    def test_get_vbu(self):
        """Test case for get_vbu

        Retrieve the vbu  # noqa: E501
        """
        pass

    def test_list_vbus(self):
        """Test case for list_vbus

        List vbus  # noqa: E501
        """
        pass

    def test_update_vbu(self):
        """Test case for update_vbu

        Update the vbu  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
