"""
    EMIL GdvService

    The EMIL GdvService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.accounting
from eis.accounting.api.vbas_api import VbasApi  # noqa: E501


class TestVbasApi(unittest.TestCase):
    """VbasApi unit test stubs"""

    def setUp(self):
        self.api = VbasApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_vba(self):
        """Test case for create_vba

        Create the vba  # noqa: E501
        """
        pass

    def test_get_vba(self):
        """Test case for get_vba

        Retrieve the vba  # noqa: E501
        """
        pass

    def test_list_vbas(self):
        """Test case for list_vbas

        List vbas  # noqa: E501
        """
        pass

    def test_update_vba(self):
        """Test case for update_vba

        Update the vba  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
